""" Module to access the Roles endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from typing import Dict, List, Union

from pydantic import BaseModel

from ...models import PatchRoleJsonBody, Role
from ..base import ApiBaseClass


class RolesApi(ApiBaseClass):
    """Endpoints for creating, getting and updating roles."""

    def get_all_roles(
        self,
    ) -> List[Role]:
        """Get a list of all the roles



        Permissions:
            `manage_system` permission is required.
        Minimum Server Version:
            5.33

        Api Reference:
            `GetAllRoles <https://api.mattermost.com/#operation/GetAllRoles>`_
        """

        url = "/roles"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = Role.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response

    def get_role(
        self,
        role_id: str,
    ) -> Role:
        """Get a role

        Get a role from the provided role id.

        Permissions:
            Requires an active session but no other permissions.
        Minimum Server Version:
            4.9

        Api Reference:
            `GetRole <https://api.mattermost.com/#operation/GetRole>`_
        """

        url = f"/roles/{role_id}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = Role.parse_obj(response.json())

            return response200
        return response

    def get_role_by_name(
        self,
        role_name: str,
    ) -> Role:
        """Get a role

        Get a role from the provided role name.

        Permissions:
            Requires an active session but no other permissions.
        Minimum Server Version:
            4.9

        Api Reference:
            `GetRoleByName <https://api.mattermost.com/#operation/GetRoleByName>`_
        """

        url = f"/roles/name/{role_name}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = Role.parse_obj(response.json())

            return response200
        return response

    def patch_role(
        self,
        role_id: str,
        *,
        json_body: Union[PatchRoleJsonBody, Dict],
    ) -> Role:
        """Patch a role

        Partially update a role by providing only the fields you want to update.
        Omitted fields will not be updated. The fields that can be updated are
        defined in the request body, all other provided fields will be ignored.

        Permissions:
            `manage_system` permission is required.
        Minimum Server Version:
            4.9

        Api Reference:
            `PatchRole <https://api.mattermost.com/#operation/PatchRole>`_
        """

        url = f"/roles/{role_id}/patch"

        if isinstance(json_body, BaseModel):
            json_json_body = json_body.dict(exclude_unset=True)
        else:
            json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.put(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = Role.parse_obj(response.json())

            return response200
        return response

    def get_roles_by_names(
        self,
        *,
        json_body: Union[List[str], Dict],
    ) -> List[Role]:
        """Get a list of roles by name

        Get a list of roles from their names.

        Permissions:
            Requires an active session but no other permissions.
        Minimum Server Version:
            4.9

        Api Reference:
            `GetRolesByNames <https://api.mattermost.com/#operation/GetRolesByNames>`_
        """

        url = "/roles/names"
        json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = Role.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response



""" Module to access the Oauth endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from typing import Any, Dict, List, Optional, Union

from pydantic import BaseModel

from ...models import CreateOAuthAppJsonBody, OAuthApp, StatusOK, UpdateOAuthAppJsonBody
from ..base import ApiBaseClass


class OauthApi(ApiBaseClass):
    """Endpoints for configuring and interacting with Mattermost as an OAuth
    2.0 service provider."""

    async def get_oauth_apps(
        self,
        *,
        page: Optional[int] = 0,
        per_page: Optional[int] = 60,
    ) -> List[OAuthApp]:
        """Get OAuth apps

        Get a page of OAuth 2.0 client applications registered with Mattermost.

        Permissions:
            With `manage_oauth` permission, the apps registered by the
            logged in user are returned. With `manage_system_wide_oauth`
            permission, all apps regardless of creator are returned.

        Api Reference:
            `GetOAuthApps <https://api.mattermost.com/#operation/GetOAuthApps>`_
        """

        url = "/oauth/apps"
        params: Dict[str, Any] = {
            "page": page,
            "per_page": per_page,
        }
        params = {k: v for k, v in params.items() if v is not None}

        request_kwargs = {
            "url": url,
            "params": params,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = OAuthApp.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response

    async def create_oauth_app(
        self,
        *,
        json_body: Union[CreateOAuthAppJsonBody, Dict],
    ) -> OAuthApp:
        """Register OAuth app

        Register an OAuth 2.0 client application with Mattermost as the service
        provider.

        Permissions:
            Must have `manage_oauth` permission.

        Api Reference:
            `CreateOAuthApp <https://api.mattermost.com/#operation/CreateOAuthApp>`_
        """

        url = "/oauth/apps"

        if isinstance(json_body, BaseModel):
            json_json_body = json_body.dict(exclude_unset=True)
        else:
            json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 201:
            response201 = OAuthApp.parse_obj(response.json())

            return response201
        return response

    async def get_oauth_app(
        self,
        app_id: str,
    ) -> OAuthApp:
        """Get an OAuth app

        Get an OAuth 2.0 client application registered with Mattermost.

        Permissions:
            If app creator, must have `mange_oauth` permission otherwise
            `manage_system_wide_oauth` permission is required.

        Api Reference:
            `GetOAuthApp <https://api.mattermost.com/#operation/GetOAuthApp>`_
        """

        url = f"/oauth/apps/{app_id}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = OAuthApp.parse_obj(response.json())

            return response200
        return response

    async def update_oauth_app(
        self,
        app_id: str,
        *,
        json_body: Union[UpdateOAuthAppJsonBody, Dict],
    ) -> OAuthApp:
        """Update an OAuth app

        Update an OAuth 2.0 client application based on OAuth struct.

        Permissions:
            If app creator, must have `mange_oauth` permission otherwise
            `manage_system_wide_oauth` permission is required.

        Api Reference:
            `UpdateOAuthApp <https://api.mattermost.com/#operation/UpdateOAuthApp>`_
        """

        url = f"/oauth/apps/{app_id}"

        if isinstance(json_body, BaseModel):
            json_json_body = json_body.dict(exclude_unset=True)
        else:
            json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.put(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = OAuthApp.parse_obj(response.json())

            return response200
        return response

    async def delete_oauth_app(
        self,
        app_id: str,
    ) -> StatusOK:
        """Delete an OAuth app

        Delete and unregister an OAuth 2.0 client application

        Permissions:
            If app creator, must have `mange_oauth` permission otherwise
            `manage_system_wide_oauth` permission is required.

        Api Reference:
            `DeleteOAuthApp <https://api.mattermost.com/#operation/DeleteOAuthApp>`_
        """

        url = f"/oauth/apps/{app_id}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.delete(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = StatusOK.parse_obj(response.json())

            return response200
        return response

    async def regenerate_oauth_app_secret(
        self,
        app_id: str,
    ) -> OAuthApp:
        """Regenerate OAuth app secret

        Regenerate the client secret for an OAuth 2.0 client application
        registered with Mattermost.

        Permissions:
            If app creator, must have `mange_oauth` permission otherwise
            `manage_system_wide_oauth` permission is required.

        Api Reference:
            `RegenerateOAuthAppSecret <https://api.mattermost.com/#operation/RegenerateOAuthAppSecret>`_
        """

        url = f"/oauth/apps/{app_id}/regen_secret"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = OAuthApp.parse_obj(response.json())

            return response200
        return response

    async def get_oauth_app_info(
        self,
        app_id: str,
    ) -> OAuthApp:
        """Get info on an OAuth app

        Get public information about an OAuth 2.0 client application registered
        with Mattermost. The application's client secret will be blanked out.

        Permissions:
            Must be authenticated.

        Api Reference:
            `GetOAuthAppInfo <https://api.mattermost.com/#operation/GetOAuthAppInfo>`_
        """

        url = f"/oauth/apps/{app_id}/info"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = OAuthApp.parse_obj(response.json())

            return response200
        return response

    async def get_authorized_oauth_apps_for_user(
        self,
        user_id: str,
        *,
        page: Optional[int] = 0,
        per_page: Optional[int] = 60,
    ) -> List[OAuthApp]:
        """Get authorized OAuth apps

        Get a page of OAuth 2.0 client applications authorized to access a
        user's account.

        Permissions:
            Must be authenticated as the user or have `edit_other_users`
            permission.

        Api Reference:
            `GetAuthorizedOAuthAppsForUser <https://api.mattermost.com/#operation/GetAuthorizedOAuthAppsForUser>`_
        """

        url = f"/users/{user_id}/oauth/apps/authorized"
        params: Dict[str, Any] = {
            "page": page,
            "per_page": per_page,
        }
        params = {k: v for k, v in params.items() if v is not None}

        request_kwargs = {
            "url": url,
            "params": params,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = OAuthApp.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response



""" A client library for accessing Mattermost API Reference """

from .client import exceptions
from .client.async_client import AsyncClient
from .client.base import ApiClientOptions
from .client.sync_client import SyncClient

__all__ = ["ApiClientOptions", "SyncClient", "AsyncClient", "exceptions"]



""" Module to access the Elasticsearch endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from ...models import StatusOK
from ..base import ApiBaseClass


class ElasticsearchApi(ApiBaseClass):
    """Endpoints for configuring and interacting with Elasticsearch."""

    async def test_elasticsearch(
        self,
    ) -> StatusOK:
        """Test Elasticsearch configuration

        Test the current Elasticsearch configuration to see if the Elasticsearch
        server can be contacted successfully.
        Optionally provide a configuration in the request body to test. If no
        valid configuration is present in the
        request body the current server configuration will be tested.

        Permissions:
            Must have `manage_system` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `TestElasticsearch <https://api.mattermost.com/#operation/TestElasticsearch>`_
        """

        url = "/elasticsearch/test"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = StatusOK.parse_obj(response.json())

            return response200
        return response

    async def purge_elasticsearch_indexes(
        self,
    ) -> StatusOK:
        """Purge all Elasticsearch indexes

        Deletes all Elasticsearch indexes and their contents. After calling this
        endpoint, it is
        necessary to schedule a new Elasticsearch indexing job to repopulate the
        indexes.

        Permissions:
            Must have `manage_system` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `PurgeElasticsearchIndexes <https://api.mattermost.com/#operation/PurgeElasticsearchIndexes>`_
        """

        url = "/elasticsearch/purge_indexes"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        async with self.client._get_httpx_client() as httpx_client:
            response = await httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = StatusOK.parse_obj(response.json())

            return response200
        return response



""" Module to access the Jobs endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from typing import Any, Dict, List, Optional, Union

from pydantic import BaseModel

from ...models import CreateJobJsonBody, Job, StatusOK
from ..base import ApiBaseClass


class JobsApi(ApiBaseClass):
    """Endpoints related to various background jobs that can be run by the
    server or separately by job servers."""

    def get_jobs(
        self,
        *,
        page: Optional[int] = 0,
        per_page: Optional[int] = 60,
    ) -> List[Job]:
        """Get the jobs.

        Get a page of jobs. Use the query parameters to modify the behaviour of
        this endpoint.

        Permissions:
            Must have `manage_jobs` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `GetJobs <https://api.mattermost.com/#operation/GetJobs>`_
        """

        url = "/jobs"
        params: Dict[str, Any] = {
            "page": page,
            "per_page": per_page,
        }
        params = {k: v for k, v in params.items() if v is not None}

        request_kwargs = {
            "url": url,
            "params": params,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = Job.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response

    def create_job(
        self,
        *,
        json_body: Union[CreateJobJsonBody, Dict],
    ) -> Job:
        """Create a new job.

        Create a new job.

        Permissions:
            Must have `manage_jobs` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `CreateJob <https://api.mattermost.com/#operation/CreateJob>`_
        """

        url = "/jobs"

        if isinstance(json_body, BaseModel):
            json_json_body = json_body.dict(exclude_unset=True)
        else:
            json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 201:
            response201 = Job.parse_obj(response.json())

            return response201
        return response

    def get_job(
        self,
        job_id: str,
    ) -> Job:
        """Get a job.

        Gets a single job.

        Permissions:
            Must have `manage_jobs` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `GetJob <https://api.mattermost.com/#operation/GetJob>`_
        """

        url = f"/jobs/{job_id}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = Job.parse_obj(response.json())

            return response200
        return response

    def download_job(
        self,
        job_id: str,
    ) -> None:
        """Download the results of a job.

        Download the result of a single job.

        Permissions:
            Must have `manage_jobs` permission.
        Minimum Server Version:
            5.28

        Api Reference:
            `DownloadJob <https://api.mattermost.com/#operation/DownloadJob>`_
        """

        url = f"/jobs/{job_id}/download"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        return response

    def cancel_job(
        self,
        job_id: str,
    ) -> StatusOK:
        """Cancel a job.

        Cancel a job.

        Permissions:
            Must have `manage_jobs` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `CancelJob <https://api.mattermost.com/#operation/CancelJob>`_
        """

        url = f"/jobs/{job_id}/cancel"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = StatusOK.parse_obj(response.json())

            return response200
        return response

    def get_jobs_by_type(
        self,
        type: str,
        *,
        page: Optional[int] = 0,
        per_page: Optional[int] = 60,
    ) -> List[Job]:
        """Get the jobs of the given type.

        Get a page of jobs of the given type. Use the query parameters to modify
        the behaviour of this endpoint.

        Permissions:
            Must have `manage_jobs` permission.
        Minimum Server Version:
            4.1

        Api Reference:
            `GetJobsByType <https://api.mattermost.com/#operation/GetJobsByType>`_
        """

        url = f"/jobs/type/{type}"
        params: Dict[str, Any] = {
            "page": page,
            "per_page": per_page,
        }
        params = {k: v for k, v in params.items() if v is not None}

        request_kwargs = {
            "url": url,
            "params": params,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = Job.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response



""" Module to access the Migrate endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from typing import Dict, Union

from pydantic import BaseModel

from ...models import MigrateAuthToLdapJsonBody, MigrateAuthToSamlJsonBody
from ..base import ApiBaseClass


class MigrateApi(ApiBaseClass):
    """ """

    def migrate_auth_to_ldap(
        self,
        *,
        json_body: Union[MigrateAuthToLdapJsonBody, Dict],
    ) -> None:
        """Migrate user accounts authentication type to LDAP.

        Migrates accounts from one authentication provider to another. For
        example, you can upgrade your authentication provider from email to
        LDAP.

        Permissions:
            Must have `manage_system` permission.
        Minimum Server Version:
            5.28

        Api Reference:
            `MigrateAuthToLdap <https://api.mattermost.com/#operation/MigrateAuthToLdap>`_
        """

        url = "/users/migrate_auth/ldap"

        if isinstance(json_body, BaseModel):
            json_json_body = json_body.dict(exclude_unset=True)
        else:
            json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        return response

    def migrate_auth_to_saml(
        self,
        *,
        json_body: Union[MigrateAuthToSamlJsonBody, Dict],
    ) -> None:
        """Migrate user accounts authentication type to SAML.

        Migrates accounts from one authentication provider to another. For
        example, you can upgrade your authentication provider from email to
        SAML.

        Permissions:
            Must have `manage_system` permission.
        Minimum Server Version:
            5.28

        Api Reference:
            `MigrateAuthToSaml <https://api.mattermost.com/#operation/MigrateAuthToSaml>`_
        """

        url = "/users/migrate_auth/saml"

        if isinstance(json_body, BaseModel):
            json_json_body = json_body.dict(exclude_unset=True)
        else:
            json_json_body = json_body

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        return response



""" Module to access the SharedChannels endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from typing import Any, Dict, List, Optional

from ...models import RemoteClusterInfo, SharedChannel
from ..base import ApiBaseClass


class SharedChannelsApi(ApiBaseClass):
    """Endpoints for getting information about shared channels."""

    def get_all_shared_channels(
        self,
        team_id: str,
        *,
        page: Optional[int] = 0,
        per_page: Optional[int] = 0,
    ) -> List[SharedChannel]:
        """Get all shared channels for team.

        Get all shared channels for a team.

        Permissions:
            Must be authenticated.
        Minimum Server Version:
            5.50

        Api Reference:
            `GetAllSharedChannels <https://api.mattermost.com/#operation/GetAllSharedChannels>`_
        """

        url = f"/sharedchannels/{team_id}"
        params: Dict[str, Any] = {
            "page": page,
            "per_page": per_page,
        }
        params = {k: v for k, v in params.items() if v is not None}

        request_kwargs = {
            "url": url,
            "params": params,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = SharedChannel.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response

    def get_remote_cluster_info(
        self,
        remote_id: str,
    ) -> RemoteClusterInfo:
        """Get remote cluster info by ID for user.

        Get remote cluster info based on remoteId.

        Permissions:
            Must be authenticated and user must belong to at least one
            channel shared with the remote cluster.
        Minimum Server Version:
            5.50

        Api Reference:
            `GetRemoteClusterInfo <https://api.mattermost.com/#operation/GetRemoteClusterInfo>`_
        """

        url = f"/sharedchannels/remote_info/{remote_id}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = RemoteClusterInfo.parse_obj(response.json())

            return response200
        return response



""" Module to access the Exports endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from ..base import ApiBaseClass


class ExportsApi(ApiBaseClass):
    """Endpoints related to export files."""

    def list_exports(
        self,
    ) -> None:
        """List export files

        Lists all available export files.

        Permissions:
            Must have `manage_system` permissions.
        Minimum Server Version:
            5.33

        Api Reference:
            `ListExports <https://api.mattermost.com/#operation/ListExports>`_
        """

        url = "/exports"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        return response

    def download_export(
        self,
        export_name: str,
    ) -> None:
        """Download an export file

        Downloads an export file.

        Permissions:
            Must have `manage_system` permissions.
        Minimum Server Version:
            5.33

        Api Reference:
            `DownloadExport <https://api.mattermost.com/#operation/DownloadExport>`_
        """

        url = f"/exports/{export_name}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        return response

    def delete_export(
        self,
        export_name: str,
    ) -> None:
        """Delete an export file

        Deletes an export file.

        Permissions:
            Must have `manage_system` permissions.
        Minimum Server Version:
            5.33

        Api Reference:
            `DeleteExport <https://api.mattermost.com/#operation/DeleteExport>`_
        """

        url = f"/exports/{export_name}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.delete(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        return response



""" Module to access the Preferences endpoints """
# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods,too-few-public-methods

from typing import Dict, List, Union

from pydantic import BaseModel

from ...models import Preference, StatusOK
from ..base import ApiBaseClass


class PreferencesApi(ApiBaseClass):
    """Endpoints for saving and modifying user preferences."""

    def get_preferences(
        self,
        user_id: str,
    ) -> List[Preference]:
        """Get the user's preferences

        Get a list of the user's preferences.

        Permissions:
            Must be logged in as the user being updated or have the
            `edit_other_users` permission.

        Api Reference:
            `GetPreferences <https://api.mattermost.com/#operation/GetPreferences>`_
        """

        url = f"/users/{user_id}/preferences"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = Preference.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response

    def update_preferences(
        self,
        user_id: str,
        *,
        json_body: Union[List[Preference], Dict],
    ) -> StatusOK:
        """Save the user's preferences

        Save a list of the user's preferences.

        Permissions:
            Must be logged in as the user being updated or have the
            `edit_other_users` permission.

        Api Reference:
            `UpdatePreferences <https://api.mattermost.com/#operation/UpdatePreferences>`_
        """

        url = f"/users/{user_id}/preferences"
        json_json_body = []
        for json_body_item_data in json_body:

            if isinstance(json_body_item_data, BaseModel):
                json_body_item = json_body_item_data.dict(exclude_unset=True)
            else:
                json_body_item = json_body_item_data

            json_json_body.append(json_body_item)

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.put(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = StatusOK.parse_obj(response.json())

            return response200
        return response

    def delete_preferences(
        self,
        user_id: str,
        *,
        json_body: Union[List[Preference], Dict],
    ) -> StatusOK:
        """Delete user's preferences

        Delete a list of the user's preferences.

        Permissions:
            Must be logged in as the user being updated or have the
            `edit_other_users` permission.

        Api Reference:
            `DeletePreferences <https://api.mattermost.com/#operation/DeletePreferences>`_
        """

        url = f"/users/{user_id}/preferences/delete"
        json_json_body = []
        for json_body_item_data in json_body:

            if isinstance(json_body_item_data, BaseModel):
                json_body_item = json_body_item_data.dict(exclude_unset=True)
            else:
                json_body_item = json_body_item_data

            json_json_body.append(json_body_item)

        request_kwargs = {
            "url": url,
            "json": json_json_body,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.post(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = StatusOK.parse_obj(response.json())

            return response200
        return response

    def get_preferences_by_category(
        self,
        user_id: str,
        category: str,
    ) -> List[Preference]:
        """List a user's preferences by category

        Lists the current user's stored preferences in the given category.

        Permissions:
            Must be logged in as the user being updated or have the
            `edit_other_users` permission.

        Api Reference:
            `GetPreferencesByCategory <https://api.mattermost.com/#operation/GetPreferencesByCategory>`_
        """

        url = f"/users/{user_id}/preferences/{category}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = []
            _response200 = response.json()
            for response200_item_data in _response200:
                response200_item = Preference.parse_obj(response200_item_data)

                response200.append(response200_item)

            return response200
        return response

    def get_preferences_by_category_by_name(
        self,
        user_id: str,
        category: str,
        preference_name: str,
    ) -> Preference:
        """Get a specific user preference

        Gets a single preference for the current user with the given category
        and name.

        Permissions:
            Must be logged in as the user being updated or have the
            `edit_other_users` permission.

        Api Reference:
            `GetPreferencesByCategoryByName <https://api.mattermost.com/#operation/GetPreferencesByCategoryByName>`_
        """

        url = f"/users/{user_id}/preferences/{category}/name/{preference_name}"

        request_kwargs = {
            "url": url,
        }
        # pylint: disable-next=protected-access
        with self.client._get_httpx_client() as httpx_client:
            response = httpx_client.get(
                **request_kwargs,
            )

        if self.skip_response_parsing:
            return response

        if response.status_code == 200:
            response200 = Preference.parse_obj(response.json())

            return response200
        return response
